#!/bin/sh

VERS="7.1.0"
DATE="2006-01-13"

# Leave the desired layout uncommented.
LAYOUT=layout1		# Tables based layout.
#LAYOUT=layout2		# CSS based simulated frames layout.

ASCIIDOC_HTML="python ../../asciidoc.py --unsafe --backend=xhtml11 --conf-file=${LAYOUT}.conf --attribute icons --attribute iconsdir=./images/icons --attribute=badges --attribute=revision=$VERS  --attribute=date=$DATE"

$ASCIIDOC_HTML --attribute=index-only index.txt
$ASCIIDOC_HTML --attribute=numbered userguide.txt
$ASCIIDOC_HTML --doctype=manpage manpage.txt
$ASCIIDOC_HTML downloads.txt
$ASCIIDOC_HTML README.txt
$ASCIIDOC_HTML CHANGELOG.txt
$ASCIIDOC_HTML README-website.txt
$ASCIIDOC_HTML a2x.1.txt
